==> KinTPV_8_236_serveur.zip: admin/_init.php <==
<?php
	// preparation de la page (inclusions divers et verification des choses indispensables  la suite)
	define('GENERAL_DIR', '../');
	define ('GENERAL_CLASSES_DIR', GENERAL_DIR.'classes');
	define ('GENERAL_CONFIG_DIR', GENERAL_DIR.'config');
	define ('CLASSES_DIR', 'classes');
	define ('GENERAL_TOOLS_DIR', GENERAL_DIR.'tools');
	
	define('PHPEXT', 'php');
	define('TPLEXT', 'tpl');
	
	define('_SMARTY_TPL_DIR_', 'templates');
	define('_SMARTY_TPL_C_DIR_', 'compile');
	define('_SMARTY_CACHE_DIR_', 'cache');
	define('_SMARTY_CONFIG_DIR_', 'config');
	
	define('_SESSION_DURATION_', 3600);
	define('_COOKIE_SESSION_', 'session');
	
	include(GENERAL_CONFIG_DIR.'/database.php');
	
	require_once(GENERAL_CLASSES_DIR.'/cloud_pref.php');
	require_once(GENERAL_CLASSES_DIR.'/db.php');
	require_once(GENERAL_CLASSES_DIR.'/cmysql.php');
	require_once(GENERAL_CLASSES_DIR.'/tools.php');
	require_once(GENERAL_CLASSES_DIR.'/user.php');
	require_once(GENERAL_CLASSES_DIR.'/magasin.php');
	require_once(GENERAL_CLASSES_DIR.'/context.php');
	require_once(CLASSES_DIR.'/session.php');
	require_once(GENERAL_TOOLS_DIR.'/phpmailer/PHPMailerAutoload.php');
	
	if((int)Tools::getValue('logout')>0)
		session::logout();
	
	if(!session::sessionOk() && !defined('_PAGE_AUTH_'))
	{
		header('location: identification.php');
		exit;
	}
	
	if(!defined('_PAGE_AUTH_'))
		session::updateSession();
	
	context::update_context();
	
	require_once(GENERAL_TOOLS_DIR.'/smarty/Smarty.class.php');
	
	$smarty = new Smarty();
	$smarty->setTemplateDir(_SMARTY_TPL_DIR_);
  $smarty->setCompileDir(_SMARTY_TPL_C_DIR_);
  $smarty->setCacheDir(_SMARTY_CACHE_DIR_);
  $smarty->setConfigDir(_SMARTY_CONFIG_DIR_);
  
  $id = Tools::getValue('id');
  
  $ident_menu = '';
  $total_record = 0;
  
  // gestion du context
  
  
?>

==> KinTPV_9_246_serveur.zip: admin/_init.php <==
<?php
	// preparation de la page (inclusions divers et verification des choses indispensables à la suite)
	define('GENERAL_DIR', '../');
	define ('GENERAL_CLASSES_DIR', GENERAL_DIR.'classes');
	define ('GENERAL_CONFIG_DIR', GENERAL_DIR.'config');
	define ('CLASSES_DIR', 'classes');
	define ('GENERAL_TOOLS_DIR', GENERAL_DIR.'tools');
	
	define('PHPEXT', 'php');
	define('TPLEXT', 'tpl');
	
	define('_SMARTY_TPL_DIR_', 'templates');
	define('_SMARTY_TPL_C_DIR_', 'compile');
	define('_SMARTY_CACHE_DIR_', 'cache');
	define('_SMARTY_CONFIG_DIR_', 'config');
	
	define('_SESSION_DURATION_', 3600);
	define('_COOKIE_SESSION_', 'session');
	
	include(GENERAL_CONFIG_DIR.'/database.php');
	
	require_once(GENERAL_CLASSES_DIR.'/cloud_pref.php');
	require_once(GENERAL_CLASSES_DIR.'/db.php');
	require_once(GENERAL_CLASSES_DIR.'/cmysql.php');
	require_once(GENERAL_CLASSES_DIR.'/tools.php');
	require_once(GENERAL_CLASSES_DIR.'/user.php');
	require_once(GENERAL_CLASSES_DIR.'/magasin.php');
	require_once(GENERAL_CLASSES_DIR.'/context.php');
	require_once(CLASSES_DIR.'/session.php');
	require_once(GENERAL_TOOLS_DIR.'/phpmailer/PHPMailerAutoload.php');
	
	if((int)Tools::getValue('logout')>0)
		session::logout();
	
	if(!session::sessionOk() && !defined('_PAGE_AUTH_'))
	{
		header('location: identification.php');
		exit;
	}
	
	if(!defined('_PAGE_AUTH_'))
		session::updateSession();
	
	context::update_context();
	
	require_once(GENERAL_TOOLS_DIR.'/smarty/Smarty.class.php');
	
	$smarty = new Smarty();
	$smarty->setTemplateDir(_SMARTY_TPL_DIR_);
  $smarty->setCompileDir(_SMARTY_TPL_C_DIR_);
  $smarty->setCacheDir(_SMARTY_CACHE_DIR_);
  $smarty->setConfigDir(_SMARTY_CONFIG_DIR_);
  
  $id = Tools::getValue('id');
  
  $ident_menu = '';
  $total_record = 0;
  
  // gestion du context
  
  
?>
